@@ -5,6 +5,11 @@ module Diakonos
       File.open( @about_filename, "w" ) do |f|
         inst = ::Diakonos::INSTALL_SETTINGS
 
+        configs = @configs.map { |h|
+          source = h[:source] ? "(included by #{h[:source]})" : ''
+          "#{h[:filename]}\t#{source}"
+        }.join("\n")
+
         ext_loaded = @extensions.loaded_extensions.sort_by { |e|
           e.name.downcase
         }.map { |e|
@@ -42,6 +47,10 @@ Help dir:           #{ inst[ :help_dir ] }
 System config dir:  #{ inst[ :conf_dir ] }
 System library dir: #{ inst[ :lib_dir ] }
 
+### Configuration Files
+
+#{ configs }
+
 ## Extensions
 
 #{ ext_loaded }
