@@ -77,7 +77,7 @@ module Diakonos
       @mark_anchor = nil
       @text_marks = Hash.new
       @selection_mode = :normal
-      @last_search_regexps = nil
+      @last_search_regexps = Array( options['last_search_regexps'] ).map { |r| Regexp.new(r) }
       @highlight_regexp = nil
       @last_search = nil
       @changing_selection = false
@@ -278,7 +278,7 @@ module Diakonos
           paste str, !TYPING, @indent_closers
           cursor_to r, c
           if /%_/ === str
-            find( [ /%_/ ], :direction => :down, :replacement => '', :auto_choice => CHOICE_YES_AND_STOP )
+            find [/%_/], direction: :down, replacement: '', auto_choice: CHOICE_YES_AND_STOP
           end
         end
       end
@@ -507,7 +507,8 @@ module Diakonos
     end
 
     def wrap_paragraph
-      start_row = end_row = @last_row
+      start_row = end_row = cursor_row = @last_row
+      cursor_col = @last_col
       until start_row == 0 || @lines[ start_row - 1 ].strip == ''
         start_row -= 1
       end
@@ -529,13 +530,14 @@ module Diakonos
         line << " #{word}"
       end
       line.strip!
-      if not line.empty?
+      if ! line.empty?
         lines << line
       end
       if @lines[ start_row...end_row ] != lines
         take_snapshot
         @lines[ start_row...end_row ] = lines
         set_modified
+        cursor_to start_row + lines.length, lines[-1].length
       end
     end
 
@@ -576,16 +578,20 @@ module Diakonos
 
       col1 = pos[ 0 ][ 1 ]
       col2 = pos[ 1 ][ 1 ]
-      @lines[ @last_row ][ col1..col2 ]
+      @lines[ @last_row ][ col1...col2 ]
     end
 
-    def word_under_cursor_pos
+    def word_under_cursor_pos( options = {} )
+      or_after = options[:or_after]
       @lines[ @last_row ].scan( WORD_REGEXP ) do |match_text|
         last_match = Regexp.last_match
-        if last_match.begin( 0 ) <= @last_col && @last_col < last_match.end( 0 )
+        if (
+          last_match.begin( 0 ) <= @last_col && @last_col < last_match.end( 0 ) ||
+          or_after && last_match.begin(0) > @last_col
+        )
           return [
             [ @last_row, last_match.begin( 0 ) ],
-            [ @last_row, last_match.end( 0 ) - 1 ],
+            [ @last_row, last_match.end( 0 ) ],
           ]
         end
       end
