@@ -97,6 +97,24 @@ module Diakonos
       end
     end
 
+    def delete_from( char )
+      remove_selection( DONT_DISPLAY )  if selection_mark
+
+      first_row = row = @last_row
+      index = @lines[ @last_row ].rindex( char, @last_col-1 )
+
+      while row > 0 && index.nil?
+        row -= 1
+        index = @lines[ row ].rindex( char )
+      end
+
+      if index
+        deleted_text = delete_from_to( row, index+1, first_row, @last_col )
+        cursor_to( row, index+1 )
+        deleted_text
+      end
+    end
+
     def delete_to_and_from( char, inclusive = NOT_INCLUSIVE )
       remove_selection( DONT_DISPLAY )  if selection_mark
 
@@ -149,4 +167,4 @@ module Diakonos
 
   end
 
-end
\ No newline at end of file
+end
