@@ -2,6 +2,8 @@ module Diakonos
 
   class Buffer
 
+    attr_reader :num_matches_found, :last_search_regexps
+
     CHARACTER_PAIRS = {
       '(' => { partner: ')', direction: :forward },
       '<' => { partner: '>', direction: :forward },
@@ -57,6 +59,7 @@ module Diakonos
     # split across newline characters.  Once the first element is found,
     # each successive element must match against lines following the first
     # element.
+    # @return [Fixnum] the number of replacements made
     def find( regexps, options = {} )
       return  if regexps.nil?
       regexp = regexps[ 0 ]
@@ -69,8 +72,13 @@ module Diakonos
       from_col           = options[ :starting_col ] || @last_col
       show_context_after = options[ :show_context_after ]
 
-      search_area = @search_area || TextMark.new( 0, 0, @lines.size - 1, @lines[ -1 ].size, nil )
+      if options[:starting]
+        @num_matches_found = nil
+      end
 
+      num_replacements = 0
+
+      search_area = @search_area || TextMark.new( 0, 0, @lines.size - 1, @lines[ -1 ].size, nil )
       if ! search_area.contains?( from_row, from_col )
         from_row, from_col = search_area.start_row, search_area.start_col
       end
@@ -189,7 +197,7 @@ module Diakonos
       if ! finding
         remove_selection DONT_DISPLAY
         clear_matches DO_DISPLAY
-        if ! options[ :quiet ]
+        if ! options[ :quiet ] && ( replacement.nil? || num_replacements == 0 )
           $diakonos.set_iline "/#{regexp.source}/ not found."
         end
       else
@@ -240,47 +248,56 @@ module Diakonos
           }
 
           choice = auto_choice || $diakonos.get_choice(
-            "Replace?",
+            "#{num_matches_found} match#{ num_matches_found != 1 ? 'es' : '' } - Replace this one?",
             [ CHOICE_YES, CHOICE_NO, CHOICE_ALL, CHOICE_CANCEL, CHOICE_YES_AND_STOP ],
             CHOICE_YES
           )
           case choice
           when CHOICE_YES
             paste [ actual_replacement ]
-            find( regexps, :direction => direction, :replacement => replacement )
+            num_replacements += 1 + find( regexps, direction: direction, replacement: replacement )
           when CHOICE_ALL
-            replace_all( regexp, replacement )
+            num_replacements += replace_all( regexp, replacement )
           when CHOICE_NO
-            find( regexps, :direction => direction, :replacement => replacement )
+            num_replacements += find( regexps, direction: direction, replacement: replacement )
           when CHOICE_CANCEL
             # Do nothing further.
           when CHOICE_YES_AND_STOP
             paste [ actual_replacement ]
+            num_replacements += 1
             # Do nothing further.
           end
         end
       end
+
+      num_replacements
     end
 
+    # @return [Fixnum] the number of replacements made
     def replace_all( regexp, replacement )
       return  if( regexp.nil? or replacement.nil? )
 
+      num_replacements = 0
+
       take_snapshot
       @lines = @lines.collect { |line|
+        num_replacements += line.scan(regexp).size
         line.gsub( regexp, replacement )
       }
       set_modified
       clear_matches
       display
+      num_replacements
     end
 
     def highlight_matches( regexp = @highlight_regexp )
       @highlight_regexp = regexp
       return  if @highlight_regexp.nil?
-      found_marks = @lines[ @top_line...(@top_line + $diakonos.main_window_height) ].grep_indices( @highlight_regexp ).collect do |line_index, start_col, end_col|
-        TextMark.new( @top_line + line_index, start_col, @top_line + line_index, end_col, @settings[ "lang.#{@language}.format.found" ] )
+      found_marks = @lines.grep_indices( @highlight_regexp ).collect do |line_index, start_col, end_col|
+        TextMark.new( line_index, start_col, line_index, end_col, @settings[ "lang.#{@language}.format.found" ] )
       end
       @text_marks[ :found ] = found_marks
+      @num_matches_found ||= found_marks.size
     end
 
     def clear_matches( do_display = DONT_DISPLAY )
@@ -375,11 +392,11 @@ module Diakonos
     end
 
     def find_again( last_search_regexps, direction = @last_search_direction )
-      if @last_search_regexps.nil?
+      if @last_search_regexps.nil? || @last_search_regexps.empty?
         @last_search_regexps = last_search_regexps
       end
       if @last_search_regexps
-        find( @last_search_regexps, :direction => direction )
+        find @last_search_regexps, direction: direction
       end
     end
 
@@ -417,7 +434,6 @@ module Diakonos
         else
           # Check the current row first.
 
-          #col_to_check = ( @last_found_col or @last_col ) - 1
           col_to_check = @last_col - 1
           if col_to_check >= 0
             index, match_text = @lines[ @last_row ].group_rindex( regexp, col_to_check )
@@ -444,11 +460,9 @@ module Diakonos
       end
 
       if found_text
-        #@last_found_row = found_row
-        #@last_found_col = found_col
         cursor_to( found_row, found_col )
-
         display
+        true
       end
     end
 
@@ -466,4 +480,4 @@ module Diakonos
 
   end
 
-end
\ No newline at end of file
+end
