@@ -11,12 +11,12 @@ class CTag
     end
     
     def to_s
-        return "#{@file}:#{@command} (#{@kind}) #{@rest}"
+        "#{@file}:#{@command} (#{@kind}) #{@rest}"
     end
     
     def == ( other )
-        return (
-            other != nil and
+        (
+            other and
             @file == other.file and
             @command == other.command and
             @kind == other.kind and
