@@ -9,7 +9,7 @@ module Diakonos
 
     def push_cursor_state( top_line, row, col, clear_stack_pointer = CLEAR_STACK_POINTER )
       new_state = {
-        buffer: @current_buffer,
+        buffer: buffer_current,
         top_line: top_line,
         row: row,
         col: col
