@@ -30,6 +30,25 @@ module Diakonos
       end
     end
 
+    # Deletes characters starting from (but not including) a given character
+    # up to (but not including) the current cursor position.
+    # Also puts the deleted text into the clipboard.
+    def delete_from( char = nil )
+      if char.nil?
+        set_iline "Type character to delete from..."
+        char = @win_main.getch
+        set_iline
+      end
+      if char
+        removed_text = buffer_current.delete_from(char)
+        if removed_text
+          @clipboard.add_clip removed_text
+        else
+          set_iline "'#{char}' not found."
+        end
+      end
+    end
+
     # Deletes characters between, but not including, a given pair of
     # characters.  Also puts the deleted text into the clipboard.
     # Brace characters are intelligently matched with their opposite-side
@@ -151,7 +170,7 @@ module Diakonos
             # TODO: let them choose "never" and "always"
           end
 
-          close_file error_file
+          close_buffer error_file
         else
           help selected
         end
@@ -229,7 +248,7 @@ module Diakonos
       @buffers.each do |buffer|
         next  if ! buffer.modified?
         switch_to buffer
-        closure_choice = close_file( buffer, to_all )
+        closure_choice = close_buffer( buffer, to_all )
         case closure_choice
         when CHOICE_CANCEL
           @quitting = false
@@ -241,7 +260,7 @@ module Diakonos
     end
 
     def repeat_last
-      eval @last_commands[ -1 ] if not @last_commands.empty?
+      eval @functions_last[ -1 ] if not @functions_last.empty?
     end
 
     # Send the Diakonos job to background, as if with Ctrl-Z
@@ -261,9 +280,24 @@ module Diakonos
       end
     end
 
-    # Undoes the latest change made to the current buffer.
+    # Undoes the latest change made to the current buffer,
+    # or reopens the file that was just closed.
     def undo( buffer = buffer_current )
-      buffer.undo
+      if @functions_last[-1] == 'close_buffer'
+        open_file(
+          @buffer_closed.name,
+          'cursor' => {
+            'row' => @buffer_closed.last_row,
+            'col' => @buffer_closed.last_col,
+          },
+          'display' => {
+            'top_line' => @buffer_closed.top_line,
+            'left_col' => @buffer_closed.left_column,
+          }
+        )
+      else
+        buffer.undo
+      end
     end
 
     # Redoes the latest change undone on the current buffer.
@@ -272,4 +306,4 @@ module Diakonos
     end
 
   end
-end
\ No newline at end of file
+end
