@@ -5,7 +5,7 @@ module Diakonos
     #
     # @see Diakonos::Buffer#delete
     def backspace
-      if( @current_buffer.changing_selection || cursor_left( Buffer::STILL_TYPING ) )
+      if( buffer_current.changing_selection || cursor_left( Buffer::STILL_TYPING ) )
         delete
       end
     end
@@ -13,18 +13,18 @@ module Diakonos
     # Insert a carriage return (newline) at the current cursor location.
     # Deletes any currently selected text.
     def carriage_return
-      @current_buffer.carriage_return
-      @current_buffer.delete_selection
+      buffer_current.carriage_return
+      buffer_current.delete_selection
     end
 
-    # Calls Buffer#delete on the current_buffer.
+    # Calls Buffer#delete on the current buffer.
     def delete
-      @current_buffer.delete
+      buffer_current.delete
     end
 
     # Deletes the current line and adds it to the clipboard.
     def delete_line
-      removed_text = @current_buffer.delete_line
+      removed_text = buffer_current.delete_line
       if removed_text
         @clipboard.add_clip( [ removed_text, "" ] )
       end
