@@ -10,7 +10,7 @@ module Diakonos
     # @return [Fixnum] the choice the user made, or nil if the user was not prompted to choose.
     # @see Diakonos::CHOICE_YES
     # @see Diakonos::CHOICE_NO
-    def close_file( buffer = buffer_current, to_all = nil )
+    def close_buffer( buffer = buffer_current, to_all = nil )
       return nil  if buffer.nil?
 
       choice = nil
@@ -83,14 +83,15 @@ module Diakonos
         end
 
         if to_switch_to
-          switch_to( to_switch_to )
+          switch_to to_switch_to
         elsif previous_buffer
-          switch_to( previous_buffer )
+          switch_to previous_buffer
         else
           # No buffers left.  Open a new blank one.
           open_file
         end
 
+        @buffer_closed = del_buffer
         @buffers.delete del_buffer
         cursor_stack_remove_buffer del_buffer
         save_session
@@ -147,6 +148,10 @@ module Diakonos
     # @option meta [Hash] 'display' (nil)
     #   A Hash containing the 'top_line' and 'left_column' to use to position
     #   the view after opening.
+    # @option meta [Boolean] 'read_only' (false)
+    #   Whether to open the file in read-only (unmodifiable) mode
+    # @option meta [Boolean] 'revert' (false)
+    #   Whether to skip asking about reverting to on-disk file contents (if different)
     # @return [Buffer] the buffer of the opened file
     # @return [NilClass] nil on failure
     def open_file( filename = nil, meta = {} )
@@ -164,7 +169,8 @@ module Diakonos
       do_open = true
       buffer = nil
       if filename
-        filename, last_row = parse_filename_and_line_number( filename )
+        filename, last_row_ = parse_filename_and_line_number( filename )
+        last_row = last_row_ || last_row
         existing_buffer = @buffers.find { |b| b.name == filename }
 
         if existing_buffer
@@ -235,7 +241,11 @@ module Diakonos
           if existing_buffer
             @buffers[ @buffers.index( existing_buffer ) ] = buffer
           else
-            @buffers << buffer
+            if @settings['open_as_first_buffer']
+              @buffers.unshift buffer
+            else
+              @buffers << buffer
+            end
           end
           run_hook_procs( :after_open, buffer )
           save_session
@@ -326,7 +336,7 @@ module Diakonos
         files.each do |f|
           open_file f
         end
-        find 'down', CASE_SENSITIVE, regexp
+        find regexp, direction: :down, case_sensitive: true
       end
     end
 
@@ -435,6 +445,10 @@ module Diakonos
     def switch_to_buffer_number( buffer_number_ )
       buffer_number = buffer_number_.to_i
       return  if buffer_number < 1
+      if @buffer_number_last && buffer_number == buffer_to_number(buffer_current)
+        buffer_number = @buffer_number_last
+      end
+      @buffer_number_last = buffer_to_number(buffer_current)
       switch_to @buffers[ buffer_number - 1 ]
     end
 
