@@ -49,12 +49,12 @@ module Diakonos
 
       orig_ptr = @cursor_stack_pointer
       case direction
-      when :backward, 'backward'
+      when :backward
         @cursor_stack_pointer = ( @cursor_stack_pointer || @cursor_stack.length ) - 1 - delta
         while different_file && @cursor_stack[ @cursor_stack_pointer ] && @cursor_stack[ @cursor_stack_pointer ][ :buffer ] == buffer_current
           @cursor_stack_pointer -= 1
         end
-      when :forward, 'forward'
+      when :forward
         @cursor_stack_pointer = ( @cursor_stack_pointer || 0 ) + 1
         while different_file && @cursor_stack[ @cursor_stack_pointer ] && @cursor_stack[ @cursor_stack_pointer ][ :buffer ] == buffer_current
           @cursor_stack_pointer += 1
@@ -252,4 +252,4 @@ module Diakonos
     end
 
   end
-end
\ No newline at end of file
+end
