@@ -2,18 +2,27 @@ module Diakonos
   module Functions
 
     # Searches for matches of a regular expression in the current buffer.
-    # @param [String] dir_str
-    #   The direction to search; 'down' (default) or 'up'.
-    # @param [Boolean] case_sensitive
-    #   Whether or not the search should be case_sensitive.  Default is insensitive.
     # @param [String] regexp_source_
     #   The regular expression to search for.
-    # @param [String] replacement
+    # @param [Hash] options
+    #   Options that alter how the search is performed
+    # @option options [Symbol] :direction (:down)
+    #   The direction to search; :down or :up.
+    # @option options [Boolean] :case_sensitive (false)
+    #   Whether or not the search should be case_sensitive.
+    # @option options [String] replacement
     #   If provided, do a find and replace, and replace matches with replacement.
+    # @option options [Boolean] :word_only (false)
+    #   Whether or not to search with word boundaries
     # @see #find_exact
     # @see #find_again
-    def find( dir_str = "down", case_sensitive = CASE_INSENSITIVE, regexp_source_ = nil, replacement = nil )
-      direction = direction_of( dir_str )
+    # @see #find_clip
+    def find( regexp_source_ = nil, options = {} )
+      direction = options[:direction] || :down
+      case_sensitive = options[:case_sensitive]
+      replacement = options[:replacement]
+      word_only = options[:word_only]
+
       if regexp_source_
         regexp_source = regexp_source_
       else
@@ -35,7 +44,15 @@ module Diakonos
           initial_text: selected_text || ""
         ) { |input|
           if input.length > 1
-            find_ direction, case_sensitive, input, nil, starting_row, starting_col, QUIET
+            regexp_source = word_only ? "\\b#{input}\\b" : input
+            find_(
+              direction: direction,
+              case_sensitive: case_sensitive,
+              regexp_source: regexp_source,
+              starting_row: starting_row,
+              starting_col: starting_col,
+              quiet: true
+            )
           else
             buffer_current.remove_selection Buffer::DONT_DISPLAY
             buffer_current.clear_matches Buffer::DO_DISPLAY
@@ -44,7 +61,19 @@ module Diakonos
       end
 
       if regexp_source
-        find_ direction, case_sensitive, regexp_source, replacement, starting_row, starting_col, NOISY
+        if word_only
+          regexp_source = "\\b#{regexp_source}\\b"
+        end
+        num_replacements = find_(
+          direction: direction,
+          case_sensitive: case_sensitive,
+          regexp_source: regexp_source,
+          replacement: replacement,
+          starting_row: starting_row,
+          starting_col: starting_col,
+          quiet: false
+        )
+        show_number_of_matches_found( replacement ? num_replacements : nil )
       elsif starting_row && starting_col
         buffer_current.clear_matches
         if @settings[ 'find.return_on_abort' ]
@@ -52,40 +81,41 @@ module Diakonos
         end
       end
     end
+
     # Searches for matches of the latest clipboard item in the current buffer.
     # Note that the clipboard item is interpreted as a regular expression.
     # Only the last line of multi-line clipboard items is used.
-    # @param [String] dir_str
-    #   The direction to search; 'down' (default) or 'up'.
+    # @param [String] direction
+    #   The direction to search.  :down (default) or :up.
     # @param [Boolean] case_sensitive
     #   Whether or not the search should be case_sensitive.  Default is insensitive.
     # @see #find
-    def find_clip( dir_str = "down", case_sensitive = CASE_INSENSITIVE )
-      find dir_str, case_sensitive, @clipboard.clip[-1]
+    def find_clip( direction = :down, case_sensitive = CASE_INSENSITIVE )
+      find @clipboard.clip[-1], direction: direction, case_sensitive: case_sensitive
     end
 
     # Search again for the most recently sought search term.
-    # @param [String] dir_str
-    #   The direction to search; 'up' or 'down'.
+    # @param [String] direction
+    #   The direction to search; :down or :up.
     # @see #find
     # @see #find_exact
-    def find_again( dir_str = nil )
-      if dir_str
-        direction = direction_of( dir_str )
+    def find_again( direction = :down )
+      if direction
         buffer_current.find_again( @last_search_regexps, direction )
       else
         buffer_current.find_again( @last_search_regexps )
       end
+      show_number_of_matches_found
     end
 
     # Search for an exact string (not a regular expression).
-    # @param [String] dir_str
-    #   The direction to search; 'down' (default) or 'up'.
+    # @param [Symbol] direction
+    #   The direction to search; :down (default) or :up.
     # @param [String] search_term_
     #   The thing to search for.
     # @see #find
     # @see #find_again
-    def find_exact( dir_str = "down", search_term_ = nil )
+    def find_exact( direction = :down, search_term_ = nil )
       buffer_current.search_area = nil
       if search_term_.nil?
         if buffer_current.changing_selection
@@ -100,7 +130,6 @@ module Diakonos
         search_term = search_term_
       end
       if search_term
-        direction = direction_of( dir_str )
         regexp = [ Regexp.new( Regexp.escape( search_term ) ) ]
         buffer_current.find( regexp, :direction => direction )
         @last_search_regexps = regexp
@@ -115,7 +144,7 @@ module Diakonos
     # Wrapper method for calling #find for search and replace.
     # @see #find
     def search_and_replace( case_sensitive = CASE_INSENSITIVE )
-      find( "down", case_sensitive, nil, ASK_REPLACEMENT )
+      find nil, case_sensitive: case_sensitive, replacement: ASK_REPLACEMENT
     end
     alias_method :find_and_replace, :search_and_replace
 
@@ -123,15 +152,28 @@ module Diakonos
     # The user is not prompted for any value.
     # @param [String] regexp_source
     #   The regular expression to search for.
-    # @param [String] dir_str
-    #   The direction to search; 'down' (default) or 'up'.
-    def seek( regexp_source, dir_str = "down" )
+    # @param [Symbol] direction
+    #   The direction to search; :down (default) or :up.
+    def seek( regexp_source, direction = :down )
       if regexp_source
-        direction = direction_of( dir_str )
         regexp = Regexp.new( regexp_source )
         buffer_current.seek( regexp, direction )
       end
     end
 
+    def show_number_of_matches_found( num_replacements = nil )
+      return  if buffer_current.num_matches_found.nil?
+
+      num_found = buffer_current.num_matches_found
+      if num_found != 1
+        plural = 'es'
+      end
+      if num_replacements
+        set_iline_if_empty "#{num_replacements} out of #{num_found} match#{plural} replaced"
+      else
+        set_iline_if_empty "#{num_found} match#{plural} found"
+      end
+    end
+
   end
-end
\ No newline at end of file
+end
