@@ -9,7 +9,7 @@ describe 'A Diakonos user can' do
   end
 
   after do
-    @d.close_file @b, Diakonos::CHOICE_NO_TO_ALL
+    @d.close_buffer @b, Diakonos::CHOICE_NO_TO_ALL
   end
 
   it 'copy selected text' do
@@ -74,20 +74,20 @@ describe 'A Diakonos user can' do
 
     @d.cursor_bof
     @d.delete_and_store_line
-    @d.last_commands << 'delete_and_store_line'
+    @d.functions_last << 'delete_and_store_line'
     @d.clipboard.clip.should.equal( [
       '#!/usr/bin/env ruby',
       '',
     ] )
     @d.delete_and_store_line
-    @d.last_commands << 'delete_and_store_line'
+    @d.functions_last << 'delete_and_store_line'
     @d.clipboard.clip.should.equal( [
       '#!/usr/bin/env ruby',
       '',
       '',
     ] )
     @d.delete_and_store_line
-    @d.last_commands << 'delete_and_store_line'
+    @d.functions_last << 'delete_and_store_line'
     @d.clipboard.clip.should.equal( [
       '#!/usr/bin/env ruby',
       '',
