@@ -9,7 +9,7 @@ describe 'A Diakonos user can' do
   end
 
   after do
-    @d.close_file @b, Diakonos::CHOICE_NO_TO_ALL
+    @d.close_buffer @b, Diakonos::CHOICE_NO_TO_ALL
   end
 
   it 'collapse whitespace' do
@@ -98,7 +98,7 @@ describe 'A Diakonos user can' do
     cursor_should_be_at 11,0
   end
 
-  it 'will not comment out blank lines' do
+  it 'not comment out blank lines' do
     @b.cursor_to 3,0
     @b.selection_mark.should.be.nil
     @b.to_a[ 3 ].should.equal ''
@@ -132,6 +132,30 @@ describe 'A Diakonos user can' do
     @b.to_a[ 5 ].should.equal '  :x, :y'
   end
 
+  it 'delete from a character' do
+    @b.cursor_to 12,11
+    @d.delete_from ' '
+    cursor_should_be_at 12,6
+    @b.to_a[12].should.equal '  def ction'
+
+    @b.cursor_to 7,6
+    @d.delete_from ' '
+    cursor_should_be_at 7,6
+    @b.to_a[7].should.equal '  def initialize'
+
+    @b.cursor_to 7,5
+    @d.delete_from ' '
+    cursor_should_be_at 7,2
+    @b.to_a[7].should.equal '   initialize'
+  end
+
+  it 'not delete from a non-existent character' do
+    @b.cursor_to 7,6
+    @d.delete_from '@'
+    @b.should.not.be.modified
+    @b.to_a[7].should.equal '  def initialize'
+  end
+
   it 'delete between matching characters' do
     @b.cursor_to 2,15
     @b.to_a[ 2 ].should.equal '# This is only a sample file used in the tests.'
@@ -283,4 +307,29 @@ describe 'A Diakonos user can' do
     @d.undo
   end
 
+  it 'word wrap paragraphs of text' do
+    @b = @d.open_file( File.join(TEST_DIR, '/lorem-ipsum.txt') )
+    @b.length.should == 2
+    cursor_should_be_at 0,0
+
+    @b.wrap_paragraph
+    @b.to_a.should == [
+      'Lorem ipsum dolor sit amet, consectetur adipiscing elit.  Donec a diam lectus.',
+      'Sed sit amet ipsum mauris.  Maecenas congue ligula ac quam viverra nec',
+      'consectetur ante hendrerit.  Donec et mollis dolor.  Praesent et diam eget',
+      'libero egestas mattis sit amet vitae augue.  Nam tincidunt congue enim, ut',
+      'porta lorem lacinia consectetur.  Donec ut libero sed arcu vehicula ultricies a',
+      'non tortor.  Lorem ipsum dolor sit amet, consectetur adipiscing elit.  Aenean',
+      'ut gravida lorem.  Ut turpis felis, pulvinar a semper sed, adipiscing id',
+      'dolor.  Pellentesque auctor nisi id magna consequat sagittis.  Curabitur',
+      'dapibus enim sit amet elit pharetra tincidunt feugiat nisl imperdiet.  Ut',
+      'convallis libero in urna ultrices accumsan.  Donec sed odio eros.  Donec',
+      'viverra mi quis quam pulvinar at malesuada arcu rhoncus.  Cum sociis natoque',
+      'penatibus et magnis dis parturient montes, nascetur ridiculus mus.  In rutrum',
+      'accumsan ultricies.  Mauris vitae nisi at sem facilisis semper ac in est.',
+      '',
+    ]
+    cursor_should_be_at 13,0
+  end
+
 end
