@@ -9,7 +9,7 @@ describe 'A Diakonos user' do
   end
 
   after do
-    @d.close_file @b, Diakonos::CHOICE_NO_TO_ALL
+    @d.close_buffer @b, Diakonos::CHOICE_NO_TO_ALL
   end
 
   it 'can grep the open buffers' do
@@ -25,6 +25,16 @@ describe 'A Diakonos user' do
     @d.close_list_buffer
   end
 
+  it 'can find words' do
+    @d.find 'is', word_only: true
+    cursor_should_be_at 2,9
+    selection_should_be 2,7, 2,9
+
+    @d.find 'InSpEcT', word_only: true
+    cursor_should_be_at 13,13
+    selection_should_be 13,6, 13,13
+  end
+
 end
 
 describe 'A Diakonos Buffer' do
@@ -36,7 +46,7 @@ describe 'A Diakonos Buffer' do
   end
 
   after do
-    @d.close_file @b, Diakonos::CHOICE_NO_TO_ALL
+    @d.close_buffer @b, Diakonos::CHOICE_NO_TO_ALL
   end
 
   it 'can find next closest characters' do
@@ -88,4 +98,4 @@ describe 'A Diakonos Buffer' do
     @b.pos_of_pair_match( 5, 13 ).should.equal [ nil, nil ]
     @b.pos_of_pair_match( 23, 0 ).should.equal [ nil, nil ]
   end
-end
\ No newline at end of file
+end
